==> jc-1.4.0.tar.gz: jas/InsnOperand.h <==
// abstract class jas.InsnOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_InsnOperand_H_
#define _JC_jas_InsnOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_InsnOperand$sub_refs	_jc_jas_InsnOperand$sub_refs;
typedef struct _jc_jas_InsnOperand$sub_nonrefs	_jc_jas_InsnOperand$sub_nonrefs;
typedef struct _jc_jas_InsnOperand$refs	_jc_jas_InsnOperand$refs;
typedef struct _jc_jas_InsnOperand$nonrefs	_jc_jas_InsnOperand$nonrefs;
typedef struct _jc_jas_InsnOperand$object	_jc_jas_InsnOperand$object;

typedef const struct _jc_jas_InsnOperand$vmethods	_jc_jas_InsnOperand$vmethods;
typedef const struct _jc_jas_InsnOperand$vtable	_jc_jas_InsnOperand$vtable;
typedef const struct _jc_jas_InsnOperand$vtype	_jc_jas_InsnOperand$vtype;

// Constructors
extern void _jc_jas_InsnOperand$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_InsnOperand$object *);

// Virtual methods
extern void _jc_jas_InsnOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_InsnOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
extern void _jc_jas_InsnOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
extern void _jc_jas_InsnOperand$method$writePrefix$829d20cc218d44c9(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_InsnOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_InsnOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_InsnOperand$method_info$write$d61e8c36d8c1cacd;
extern _jc_method _jc_jas_InsnOperand$method_info$writePrefix$829d20cc218d44c9;

// Virtual methods structure
struct _jc_jas_InsnOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
	void	(*writePrefix$829d20cc218d44c9)(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_InsnOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
};

// Vtype
struct _jc_jas_InsnOperand$vtype {
	_jc_type			type;
	_jc_jas_InsnOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_InsnOperand$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_InsnOperand$refs {
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_InsnOperand$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_InsnOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
};

// Object instance structure
struct _jc_jas_InsnOperand$object {
	_jc_jas_InsnOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_InsnOperand$vtype	*vtype;
	_jc_jas_InsnOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_InsnOperand$vtype _jc_jas_InsnOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_InsnOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_InsnOperand$class_object;

#endif	/* _JC_jas_InsnOperand_H_ */

==> jc-1.4.6.tar.gz: jas/InsnOperand.h <==
// abstract class jas.InsnOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_InsnOperand_H_
#define _JC_jas_InsnOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_InsnOperand$sub_refs	_jc_jas_InsnOperand$sub_refs;
typedef struct _jc_jas_InsnOperand$sub_nonrefs	_jc_jas_InsnOperand$sub_nonrefs;
typedef struct _jc_jas_InsnOperand$refs	_jc_jas_InsnOperand$refs;
typedef struct _jc_jas_InsnOperand$nonrefs	_jc_jas_InsnOperand$nonrefs;
typedef struct _jc_jas_InsnOperand$object	_jc_jas_InsnOperand$object;

typedef const struct _jc_jas_InsnOperand$vmethods	_jc_jas_InsnOperand$vmethods;
typedef const struct _jc_jas_InsnOperand$vtable	_jc_jas_InsnOperand$vtable;
typedef const struct _jc_jas_InsnOperand$vtype	_jc_jas_InsnOperand$vtype;

// Constructors
extern void _jc_jas_InsnOperand$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_InsnOperand$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_InsnOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_InsnOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_InsnOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_jas_InsnOperand$method$writePrefix$829d20cc218d44c9(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_InsnOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_InsnOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_InsnOperand$method_info$write$d61e8c36d8c1cacd;
extern _jc_method _jc_jas_InsnOperand$method_info$writePrefix$829d20cc218d44c9;

// Virtual methods structure
struct _jc_jas_InsnOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
	void	(*writePrefix$829d20cc218d44c9)(_jc_env *, struct _jc_jas_InsnOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_InsnOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
};

// Vtype
struct _jc_jas_InsnOperand$vtype {
	_jc_type			type;
	_jc_jas_InsnOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_InsnOperand$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_InsnOperand$refs {
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_InsnOperand$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_InsnOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
};

// Object instance structure
struct _jc_jas_InsnOperand$object {
	_jc_jas_InsnOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_InsnOperand$vtype	*vtype;
	_jc_jas_InsnOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_InsnOperand$vtype _jc_jas_InsnOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_InsnOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_InsnOperand$class_object;

#endif	/* _JC_jas_InsnOperand_H_ */
